@@ -75,7 +75,7 @@ bool Attribute::read(StarZone &zone, StarObject &object)
   if (fl&0x20) *input >> nEnd;
   m_position=STOFFVec2i(nBegin==0xFFFF ? -1 : int(nBegin), nEnd==0xFFFF ? -1 : int(nEnd));
 
-  int which=int(nWhich);
+  auto which=int(nWhich);
   if (which>0x6001 && zone.getDocumentVersion()!=0x0219) // bug correction 0x95500
     which+=15;
   if (which>=0x1000 && which<=0x1024) which+=-0x1000+int(StarAttribute::ATTR_CHR_CASEMAP);
@@ -186,14 +186,14 @@ bool Bookmark::read(StarZone &zone)
     zone.closeFlagZone();
   }
   if (ok && input->tell()<zone.getRecordLastPosition()) {
-    for (int i=0; i<4; ++i) { // start[aMac:aLib],end[aMac:Alib]
+    for (auto &macroName : m_macroNames) {  // start[aMac:aLib],end[aMac:Alib]
       if (!zone.readString(text)) {
         STOFF_DEBUG_MSG(("StarWriterStruct::Bookmark::read: can not read macro name\n"));
         f << "###macro";
         break;
       }
       else
-        m_macroNames[i]=libstoff::getString(text);
+        macroName=libstoff::getString(text);
     }
   }
 
@@ -311,7 +311,7 @@ bool DatabaseName::read(StarZone &zone)
     m_names[1]=libstoff::getString(text);
   }
   if (zone.isCompatibleWith(0x12,0x22, 0x101)) {
-    int nCount=int(input->readULong(2));
+    auto nCount=int(input->readULong(2));
     if (nCount>0 && zone.isCompatibleWith(0x28)) {
       for (int i=0; i<nCount; ++i) {
         if (input->tell()>=zone.getRecordLastPosition()) {
@@ -327,7 +327,7 @@ bool DatabaseName::read(StarZone &zone)
         }
         data.m_name=libstoff::getString(text);
         int positions[2];
-        for (int j=0; j<2; ++j) positions[j]=int(input->readULong(4));
+        for (int &position : positions) position=int(input->readULong(4));
         data.m_selection=STOFFVec2i(positions[0],positions[1]);
         m_dataList.push_back(data);
       }
@@ -344,14 +344,14 @@ std::ostream &operator<<(std::ostream &o, DatabaseName const &dbase)
 {
   for (int i=0; i<2; ++i) {
     if (dbase.m_names[i].empty()) continue;
-    char const *(wh[])= {"name[database]", "name[table]"};
+    char const *wh[]= {"name[database]", "name[table]"};
     o << wh[i] << "=" << dbase.m_names[i].cstr() << ",";
   }
   if (!dbase.m_sql.empty()) o << "sql=" << dbase.m_sql.cstr() << ",";
   if (!dbase.m_dataList.empty()) {
     o << "data=[";
-    for (size_t i=0; i<dbase.m_dataList.size(); ++i)
-      o << "[" << dbase.m_dataList[i] << "],";
+    for (auto const &data : dbase.m_dataList)
+      o << "[" << data << "],";
     o << "],";
   }
   return o;
@@ -402,8 +402,8 @@ std::ostream &operator<<(std::ostream &o, Dictionary const &dbase)
 {
   if (!dbase.m_dataList.empty()) {
     o << "data=[";
-    for (size_t i=0; i<dbase.m_dataList.size(); ++i)
-      o << "[" << dbase.m_dataList[i] << "],";
+    for (auto const &data : dbase.m_dataList)
+      o << "[" << data << "],";
     o << "],";
   }
   return o;
@@ -448,7 +448,7 @@ std::ostream &operator<<(std::ostream &o, DocStats const &stats)
 {
   for (int i=0; i<7; ++i) {
     if (!stats.m_numbers[i]) continue;
-    char const *(wh[])= {"table", "graph", "ole", "page", "paragraph", "word", "char"};
+    char const *wh[]= {"table", "graph", "ole", "page", "paragraph", "word", "char"};
     o << "num[" << wh[i] << "]=" << stats.m_numbers[i] << ",";
   }
   if (stats.m_isModified) o << "modified,";
@@ -473,7 +473,7 @@ bool Macro::read(StarZone &zone)
   f << "Entries(StarMacro)[" << zone.getRecordLevel() << "]:";
   m_key=int(input->readULong(2));
   bool ok=true;
-  for (int i=0; i<2; ++i) {
+  for (auto &name : m_names) {
     std::vector<uint32_t> string;
     if (!zone.readString(string)) {
       STOFF_DEBUG_MSG(("StarObjectText::readSWMacroTable: can not read a string\n"));
@@ -481,7 +481,7 @@ bool Macro::read(StarZone &zone)
       ok=false;
       break;
     }
-    m_names[i]=libstoff::getString(string);
+    name=libstoff::getString(string);
   }
   if (ok && zone.isCompatibleWith(0x102))
     m_scriptType=int(input->readULong(2));
@@ -699,13 +699,13 @@ std::ostream &operator<<(std::ostream &o, NoteInfo const &info)
   if (info.m_type) o << "type=" << info.m_type << ",";
   for (int i=0; i<4; ++i) {
     if (info.m_idx[i]==0xFFFF) continue;
-    char const *(wh[])= {"pageId", "collIdx", "charIdx", "anchorCharIdx"};
+    char const *wh[]= {"pageId", "collIdx", "charIdx", "anchorCharIdx"};
     o << wh[i] << "=" << info.m_idx[i] << ",";
   }
   if (info.m_ftnOffset) o << "ftnOffset=" << info.m_ftnOffset << ",";
   for (int i=0; i<4; ++i) {
     if (info.m_strings[i].empty()) continue;
-    char const *(wh[])= {"prefix", "suffix", "quoValis", "ergoSum"};
+    char const *wh[]= {"prefix", "suffix", "quoValis", "ergoSum"};
     o << wh[i] << "=" << info.m_strings[i].cstr() << ",";
   }
   if (info.m_posType) o << "type[pos]=" << info.m_posType << ",";
@@ -732,9 +732,9 @@ bool PrintData::read(StarZone &zone)
   f << "Entries(StarPrintData)[" << zone.getRecordLevel() << "]:";
   m_flags=int(input->readULong(1));
   int dim[2];
-  for (int i=0; i<2; ++i) dim[i]=int(input->readULong(2));
+  for (int &i : dim) i=int(input->readULong(2));
   m_colRow=STOFFVec2i(dim[1],dim[0]);
-  for (int i=0; i<6; ++i) m_spacings[i]=int(input->readULong(2));
+  for (int &spacing : m_spacings) spacing=int(input->readULong(2));
   f << *this;
   ascFile.addPos(pos);
   ascFile.addNote(f.str().c_str());
@@ -749,7 +749,7 @@ std::ostream &operator<<(std::ostream &o, PrintData const &info)
   if (info.m_colRow[1]!=1) o << "rows=" << info.m_colRow[1] << ",";
   for (int i=0; i<6; ++i) {
     if (!info.m_spacings[i]) continue;
-    char const *(wh[])= {"left", "right", "top", "bottom", "horizontal", "vertical"};
+    char const *wh[]= {"left", "right", "top", "bottom", "horizontal", "vertical"};
     o << wh[i] << "=" << info.m_spacings[i] << ",";
   }
   return o;
@@ -807,7 +807,7 @@ bool Redline::readList(StarZone &zone, std::vector<Redline> &redlineList)
   // sw_sw3misc.cxx InRedlines
   f << "Entries(StarRedline)[list-" << zone.getRecordLevel() << "]:";
   zone.openFlagZone();
-  int N=int(input->readULong(2));
+  auto N=int(input->readULong(2));
   zone.closeFlagZone();
   ascFile.addPos(pos);
   ascFile.addNote(f.str().c_str());
@@ -933,7 +933,7 @@ bool TOX::read(StarZone &zone, StarObject &object)
       f << "aDummy=" << libstoff::getString(string).cstr() << ",";
   }
 
-  int N=int(input->readULong(1));
+  auto N=int(input->readULong(1));
   f << "nPatterns=" << N << ",";
   bool ok=true;
   for (int i=0; i<N; ++i) { // storeme
@@ -957,7 +957,7 @@ bool TOX::read(StarZone &zone, StarObject &object)
   for (int i=0; i<N; ++i) {
     Style style;
     style.m_level=int(input->readULong(1));
-    int nCount=int(input->readULong(2));
+    auto nCount=int(input->readULong(2));
     f << "nCount=" << nCount << ",";
     if (input->tell()+2*nCount>lastRecordPos) {
       STOFF_DEBUG_MSG(("StarWriterStruct::TOX::read: can not read some string id\n"));
@@ -967,7 +967,7 @@ bool TOX::read(StarZone &zone, StarObject &object)
     }
     librevenge::RVNGString poolName;
     for (int j=0; j<nCount; ++j) {
-      int val=int(input->readULong(2));
+      auto val=int(input->readULong(2));
       if (!zone.getPoolName(val, poolName))
         f << "###nPoolId=" << val << ",";
       else
@@ -988,7 +988,7 @@ bool TOX::read(StarZone &zone, StarObject &object)
 
   if ((fl&0x10)) {
     while (input->tell()<lastRecordPos && input->peek()=='s') {
-      shared_ptr<StarFormatManagerInternal::FormatDef> format;
+      std::shared_ptr<StarFormatManagerInternal::FormatDef> format;
       if (!object.getFormatManager()->readSWFormatDef(zone,'s', format, object)) {
         STOFF_DEBUG_MSG(("StarWriterStruct::TOX::read: can not read some format\n"));
         f << "###format,";
@@ -1043,7 +1043,7 @@ std::ostream &operator<<(std::ostream &o, TOX const &tox)
   if (tox.m_captionDisplay) o << "captionDisplay=" << tox.m_captionDisplay << ",";
   for (int i=0; i<3; ++i) {
     if (tox.m_stringIds[i]==0xFFFF) continue;
-    char const *(wh[])= {"stringId", "seqStringId", "sectStringId"};
+    char const *wh[]= {"stringId", "seqStringId", "sectStringId"};
     o << wh[i] << "=" << tox.m_stringIds[i] << ",";
   }
   if (tox.m_styleId!=0xFFFF) o << "styleId=" << tox.m_styleId << ",";
@@ -1054,18 +1054,18 @@ std::ostream &operator<<(std::ostream &o, TOX const &tox)
   if (tox.m_OLEOptions) o << "OLEOptions=" << tox.m_OLEOptions << ",";
   if (!tox.m_stringIdList.empty()) {
     o << "stringIdList=[";
-    for (size_t i=0; i<tox.m_stringIdList.size(); ++i) {
-      if (tox.m_stringIdList[i]==0xFFFF)
+    for (auto const &id : tox.m_stringIdList) {
+      if (id==0xFFFF)
         o << "_,";
       else
-        o << tox.m_stringIdList[i] << ",";
+        o << id << ",";
     }
     o << "],";
   }
   if (!tox.m_styleList.empty()) {
     o << "styleList=[";
-    for (size_t i=0; i<tox.m_styleList.size(); ++i)
-      o << "[" << tox.m_styleList[i] << "],";
+    for (auto const &style : tox.m_styleList)
+      o << "[" << style << "],";
     o << "],";
   }
   if (tox.m_titleLength) o << "titleLength=" << tox.m_titleLength << ",";
@@ -1096,7 +1096,7 @@ bool TOX51::read(StarZone &zone, StarObject &/*object*/)
   f << "Entries(StarTox51)[" << type << "-" << zone.getRecordLevel() << "]:";
   std::vector<uint32_t> string;
   if (zone.isCompatibleWith(0x201)) {
-    int strId=int(input->readULong(2));
+    auto strId=int(input->readULong(2));
     if (strId!=0xFFFF && !zone.getPoolName(strId, m_typeName))
       f << "###nPoolId=" << strId << ",";
   }
@@ -1126,7 +1126,7 @@ bool TOX51::read(StarZone &zone, StarObject &/*object*/)
   if (zone.isCompatibleWith(0x213) && (fl&0x10))
     m_firstTabPos=int(input->readULong(2));
 
-  int N=int(input->readULong(1));
+  auto N=int(input->readULong(1));
   bool ok=true;
   for (int i=0; i<N; ++i) {
     if (!zone.readString(string)) {
@@ -1197,17 +1197,17 @@ std::ostream &operator<<(std::ostream &o, TOX51 const &tox)
   if (!tox.m_title.empty()) o << "title=" << tox.m_title.cstr() << ",";
   if (!tox.m_patternList.empty()) {
     o << "patternList=[";
-    for (size_t i=0; i<tox.m_patternList.size(); ++i)
-      o << tox.m_patternList[i].cstr() << ",";
+    for (auto const &pattern : tox.m_patternList)
+      o << pattern.cstr() << ",";
     o << "],";
   }
   if (!tox.m_stringIdList.empty()) {
     o << "stringIdList=[";
-    for (size_t i=0; i<tox.m_stringIdList.size(); ++i) {
-      if (tox.m_stringIdList[i]==0xFFFF)
+    for (auto const &id : tox.m_stringIdList) {
+      if (id==0xFFFF)
         o << "_,";
       else
-        o << tox.m_stringIdList[i] << ",";
+        o << id << ",";
     }
     o << "],";
   }
